@@ -1,4 +1,5 @@
 from .auth import __THMAuth
+from .instance import __THMInstance
 from .koth import __THMKoth
 from .leaderboard import __THMLeaderboard
 from .room import __THMRoom
@@ -7,8 +8,6 @@ from .team import __THMTeam
 from .user import __THMUser
 import requests
 
-from .vpn import __THMVpn
-
 
 class THM(
     __THMAuth,
@@ -18,7 +17,7 @@ class THM(
     __THMUser,
     __THMKoth,
     __THMRoom,
-    __THMVpn
+    __THMInstance
 ):
     """
     TryHackMe API Wrapper
